# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2
from flyteidl.admin import description_entity_pb2 as flyteidl_dot_admin_dot_description__entity__pb2
from flyteidl.admin import event_pb2 as flyteidl_dot_admin_dot_event__pb2
from flyteidl.admin import execution_pb2 as flyteidl_dot_admin_dot_execution__pb2
from flyteidl.admin import launch_plan_pb2 as flyteidl_dot_admin_dot_launch__plan__pb2
from flyteidl.admin import matchable_resource_pb2 as flyteidl_dot_admin_dot_matchable__resource__pb2
from flyteidl.admin import node_execution_pb2 as flyteidl_dot_admin_dot_node__execution__pb2
from flyteidl.admin import project_attributes_pb2 as flyteidl_dot_admin_dot_project__attributes__pb2
from flyteidl.admin import project_domain_attributes_pb2 as flyteidl_dot_admin_dot_project__domain__attributes__pb2
from flyteidl.admin import project_pb2 as flyteidl_dot_admin_dot_project__pb2
from flyteidl.admin import task_execution_pb2 as flyteidl_dot_admin_dot_task__execution__pb2
from flyteidl.admin import task_pb2 as flyteidl_dot_admin_dot_task__pb2
from flyteidl.admin import version_pb2 as flyteidl_dot_admin_dot_version__pb2
from flyteidl.admin import workflow_attributes_pb2 as flyteidl_dot_admin_dot_workflow__attributes__pb2
from flyteidl.admin import workflow_pb2 as flyteidl_dot_admin_dot_workflow__pb2


class AdminServiceStub(object):
    """The following defines an RPC service that is also served over HTTP via grpc-gateway.
    Standard response codes for both are defined here: https://github.com/grpc-ecosystem/grpc-gateway/blob/master/runtime/errors.go
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTask = channel.unary_unary(
                '/flyteidl.service.AdminService/CreateTask',
                request_serializer=flyteidl_dot_admin_dot_task__pb2.TaskCreateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_task__pb2.TaskCreateResponse.FromString,
                )
        self.GetTask = channel.unary_unary(
                '/flyteidl.service.AdminService/GetTask',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_task__pb2.Task.FromString,
                )
        self.ListTaskIds = channel.unary_unary(
                '/flyteidl.service.AdminService/ListTaskIds',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.FromString,
                )
        self.ListTasks = channel.unary_unary(
                '/flyteidl.service.AdminService/ListTasks',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_task__pb2.TaskList.FromString,
                )
        self.CreateWorkflow = channel.unary_unary(
                '/flyteidl.service.AdminService/CreateWorkflow',
                request_serializer=flyteidl_dot_admin_dot_workflow__pb2.WorkflowCreateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_workflow__pb2.WorkflowCreateResponse.FromString,
                )
        self.GetWorkflow = channel.unary_unary(
                '/flyteidl.service.AdminService/GetWorkflow',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_workflow__pb2.Workflow.FromString,
                )
        self.ListWorkflowIds = channel.unary_unary(
                '/flyteidl.service.AdminService/ListWorkflowIds',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.FromString,
                )
        self.ListWorkflows = channel.unary_unary(
                '/flyteidl.service.AdminService/ListWorkflows',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_workflow__pb2.WorkflowList.FromString,
                )
        self.CreateLaunchPlan = channel.unary_unary(
                '/flyteidl.service.AdminService/CreateLaunchPlan',
                request_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanCreateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanCreateResponse.FromString,
                )
        self.GetLaunchPlan = channel.unary_unary(
                '/flyteidl.service.AdminService/GetLaunchPlan',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlan.FromString,
                )
        self.GetActiveLaunchPlan = channel.unary_unary(
                '/flyteidl.service.AdminService/GetActiveLaunchPlan',
                request_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.ActiveLaunchPlanRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlan.FromString,
                )
        self.ListActiveLaunchPlans = channel.unary_unary(
                '/flyteidl.service.AdminService/ListActiveLaunchPlans',
                request_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.ActiveLaunchPlanListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanList.FromString,
                )
        self.ListLaunchPlanIds = channel.unary_unary(
                '/flyteidl.service.AdminService/ListLaunchPlanIds',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.FromString,
                )
        self.ListLaunchPlans = channel.unary_unary(
                '/flyteidl.service.AdminService/ListLaunchPlans',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanList.FromString,
                )
        self.UpdateLaunchPlan = channel.unary_unary(
                '/flyteidl.service.AdminService/UpdateLaunchPlan',
                request_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanUpdateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanUpdateResponse.FromString,
                )
        self.CreateExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/CreateExecution',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.FromString,
                )
        self.RelaunchExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/RelaunchExecution',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionRelaunchRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.FromString,
                )
        self.RecoverExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/RecoverExecution',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionRecoverRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.FromString,
                )
        self.GetExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/GetExecution',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.Execution.FromString,
                )
        self.UpdateExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/UpdateExecution',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionUpdateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionUpdateResponse.FromString,
                )
        self.GetExecutionData = channel.unary_unary(
                '/flyteidl.service.AdminService/GetExecutionData',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetDataRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetDataResponse.FromString,
                )
        self.ListExecutions = channel.unary_unary(
                '/flyteidl.service.AdminService/ListExecutions',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionList.FromString,
                )
        self.TerminateExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/TerminateExecution',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionTerminateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionTerminateResponse.FromString,
                )
        self.GetNodeExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/GetNodeExecution',
                request_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecution.FromString,
                )
        self.GetDynamicNodeWorkflow = channel.unary_unary(
                '/flyteidl.service.AdminService/GetDynamicNodeWorkflow',
                request_serializer=flyteidl_dot_admin_dot_node__execution__pb2.GetDynamicNodeWorkflowRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.DynamicNodeWorkflowResponse.FromString,
                )
        self.ListNodeExecutions = channel.unary_unary(
                '/flyteidl.service.AdminService/ListNodeExecutions',
                request_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionList.FromString,
                )
        self.ListNodeExecutionsForTask = channel.unary_unary(
                '/flyteidl.service.AdminService/ListNodeExecutionsForTask',
                request_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionForTaskListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionList.FromString,
                )
        self.GetNodeExecutionData = channel.unary_unary(
                '/flyteidl.service.AdminService/GetNodeExecutionData',
                request_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetDataRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetDataResponse.FromString,
                )
        self.RegisterProject = channel.unary_unary(
                '/flyteidl.service.AdminService/RegisterProject',
                request_serializer=flyteidl_dot_admin_dot_project__pb2.ProjectRegisterRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__pb2.ProjectRegisterResponse.FromString,
                )
        self.UpdateProject = channel.unary_unary(
                '/flyteidl.service.AdminService/UpdateProject',
                request_serializer=flyteidl_dot_admin_dot_project__pb2.Project.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__pb2.ProjectUpdateResponse.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/flyteidl.service.AdminService/GetProject',
                request_serializer=flyteidl_dot_admin_dot_project__pb2.ProjectGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__pb2.Project.FromString,
                )
        self.ListProjects = channel.unary_unary(
                '/flyteidl.service.AdminService/ListProjects',
                request_serializer=flyteidl_dot_admin_dot_project__pb2.ProjectListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__pb2.Projects.FromString,
                )
        self.GetDomains = channel.unary_unary(
                '/flyteidl.service.AdminService/GetDomains',
                request_serializer=flyteidl_dot_admin_dot_project__pb2.GetDomainRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__pb2.GetDomainsResponse.FromString,
                )
        self.CreateWorkflowEvent = channel.unary_unary(
                '/flyteidl.service.AdminService/CreateWorkflowEvent',
                request_serializer=flyteidl_dot_admin_dot_event__pb2.WorkflowExecutionEventRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_event__pb2.WorkflowExecutionEventResponse.FromString,
                )
        self.CreateNodeEvent = channel.unary_unary(
                '/flyteidl.service.AdminService/CreateNodeEvent',
                request_serializer=flyteidl_dot_admin_dot_event__pb2.NodeExecutionEventRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_event__pb2.NodeExecutionEventResponse.FromString,
                )
        self.CreateTaskEvent = channel.unary_unary(
                '/flyteidl.service.AdminService/CreateTaskEvent',
                request_serializer=flyteidl_dot_admin_dot_event__pb2.TaskExecutionEventRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_event__pb2.TaskExecutionEventResponse.FromString,
                )
        self.GetTaskExecution = channel.unary_unary(
                '/flyteidl.service.AdminService/GetTaskExecution',
                request_serializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecution.FromString,
                )
        self.ListTaskExecutions = channel.unary_unary(
                '/flyteidl.service.AdminService/ListTaskExecutions',
                request_serializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionList.FromString,
                )
        self.GetTaskExecutionData = channel.unary_unary(
                '/flyteidl.service.AdminService/GetTaskExecutionData',
                request_serializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetDataRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetDataResponse.FromString,
                )
        self.UpdateProjectDomainAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/UpdateProjectDomainAttributes',
                request_serializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesUpdateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesUpdateResponse.FromString,
                )
        self.GetProjectDomainAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/GetProjectDomainAttributes',
                request_serializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesGetResponse.FromString,
                )
        self.DeleteProjectDomainAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/DeleteProjectDomainAttributes',
                request_serializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesDeleteRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesDeleteResponse.FromString,
                )
        self.UpdateProjectAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/UpdateProjectAttributes',
                request_serializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesUpdateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesUpdateResponse.FromString,
                )
        self.GetProjectAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/GetProjectAttributes',
                request_serializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesGetResponse.FromString,
                )
        self.DeleteProjectAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/DeleteProjectAttributes',
                request_serializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesDeleteRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesDeleteResponse.FromString,
                )
        self.UpdateWorkflowAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/UpdateWorkflowAttributes',
                request_serializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesUpdateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesUpdateResponse.FromString,
                )
        self.GetWorkflowAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/GetWorkflowAttributes',
                request_serializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesGetResponse.FromString,
                )
        self.DeleteWorkflowAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/DeleteWorkflowAttributes',
                request_serializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesDeleteRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesDeleteResponse.FromString,
                )
        self.ListMatchableAttributes = channel.unary_unary(
                '/flyteidl.service.AdminService/ListMatchableAttributes',
                request_serializer=flyteidl_dot_admin_dot_matchable__resource__pb2.ListMatchableAttributesRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_matchable__resource__pb2.ListMatchableAttributesResponse.FromString,
                )
        self.ListNamedEntities = channel.unary_unary(
                '/flyteidl.service.AdminService/ListNamedEntities',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityList.FromString,
                )
        self.GetNamedEntity = channel.unary_unary(
                '/flyteidl.service.AdminService/GetNamedEntity',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntity.FromString,
                )
        self.UpdateNamedEntity = channel.unary_unary(
                '/flyteidl.service.AdminService/UpdateNamedEntity',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityUpdateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityUpdateResponse.FromString,
                )
        self.GetVersion = channel.unary_unary(
                '/flyteidl.service.AdminService/GetVersion',
                request_serializer=flyteidl_dot_admin_dot_version__pb2.GetVersionRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_version__pb2.GetVersionResponse.FromString,
                )
        self.GetDescriptionEntity = channel.unary_unary(
                '/flyteidl.service.AdminService/GetDescriptionEntity',
                request_serializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntity.FromString,
                )
        self.ListDescriptionEntities = channel.unary_unary(
                '/flyteidl.service.AdminService/ListDescriptionEntities',
                request_serializer=flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntityListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntityList.FromString,
                )
        self.GetExecutionMetrics = channel.unary_unary(
                '/flyteidl.service.AdminService/GetExecutionMetrics',
                request_serializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetMetricsRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetMetricsResponse.FromString,
                )


class AdminServiceServicer(object):
    """The following defines an RPC service that is also served over HTTP via grpc-gateway.
    Standard response codes for both are defined here: https://github.com/grpc-ecosystem/grpc-gateway/blob/master/runtime/errors.go
    """

    def CreateTask(self, request, context):
        """Create and upload a :ref:`ref_flyteidl.admin.Task` definition
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTask(self, request, context):
        """Fetch a :ref:`ref_flyteidl.admin.Task` definition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTaskIds(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.NamedEntityIdentifier` of task objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTasks(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.Task` definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWorkflow(self, request, context):
        """Create and upload a :ref:`ref_flyteidl.admin.Workflow` definition
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkflow(self, request, context):
        """Fetch a :ref:`ref_flyteidl.admin.Workflow` definition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkflowIds(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.NamedEntityIdentifier` of workflow objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkflows(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.Workflow` definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLaunchPlan(self, request, context):
        """Create and upload a :ref:`ref_flyteidl.admin.LaunchPlan` definition
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLaunchPlan(self, request, context):
        """Fetch a :ref:`ref_flyteidl.admin.LaunchPlan` definition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveLaunchPlan(self, request, context):
        """Fetch the active version of a :ref:`ref_flyteidl.admin.LaunchPlan`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListActiveLaunchPlans(self, request, context):
        """List active versions of :ref:`ref_flyteidl.admin.LaunchPlan`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLaunchPlanIds(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.NamedEntityIdentifier` of launch plan objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLaunchPlans(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.LaunchPlan` definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLaunchPlan(self, request, context):
        """Updates the status of a registered :ref:`ref_flyteidl.admin.LaunchPlan`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateExecution(self, request, context):
        """Triggers the creation of a :ref:`ref_flyteidl.admin.Execution`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RelaunchExecution(self, request, context):
        """Triggers the creation of an identical :ref:`ref_flyteidl.admin.Execution`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecoverExecution(self, request, context):
        """Recreates a previously-run workflow execution that will only start executing from the last known failure point.
        In Recover mode, users cannot change any input parameters or update the version of the execution.
        This is extremely useful to recover from system errors and byzantine faults like - Loss of K8s cluster, bugs in platform or instability, machine failures,
        downstream system failures (downstream services), or simply to recover executions that failed because of retry exhaustion and should complete if tried again.
        See :ref:`ref_flyteidl.admin.ExecutionRecoverRequest` for more details.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecution(self, request, context):
        """Fetches a :ref:`ref_flyteidl.admin.Execution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateExecution(self, request, context):
        """Update execution belonging to project domain :ref:`ref_flyteidl.admin.Execution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecutionData(self, request, context):
        """Fetches input and output data for a :ref:`ref_flyteidl.admin.Execution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExecutions(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.Execution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TerminateExecution(self, request, context):
        """Terminates an in-progress :ref:`ref_flyteidl.admin.Execution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodeExecution(self, request, context):
        """Fetches a :ref:`ref_flyteidl.admin.NodeExecution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDynamicNodeWorkflow(self, request, context):
        """Fetches a :ref:`ref_flyteidl.admin.DynamicNodeWorkflowResponse`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNodeExecutions(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.NodeExecution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNodeExecutionsForTask(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.NodeExecution` launched by the reference :ref:`ref_flyteidl.admin.TaskExecution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodeExecutionData(self, request, context):
        """Fetches input and output data for a :ref:`ref_flyteidl.admin.NodeExecution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterProject(self, request, context):
        """Registers a :ref:`ref_flyteidl.admin.Project` with the Flyte deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProject(self, request, context):
        """Updates an existing :ref:`ref_flyteidl.admin.Project`
        flyteidl.admin.Project should be passed but the domains property should be empty;
        it will be ignored in the handler as domains cannot be updated via this API.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """Fetches a :ref:`ref_flyteidl.admin.Project`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjects(self, request, context):
        """Fetches a list of :ref:`ref_flyteidl.admin.Project`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWorkflowEvent(self, request, context):
        """Indicates a :ref:`ref_flyteidl.event.WorkflowExecutionEvent` has occurred.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNodeEvent(self, request, context):
        """Indicates a :ref:`ref_flyteidl.event.NodeExecutionEvent` has occurred.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTaskEvent(self, request, context):
        """Indicates a :ref:`ref_flyteidl.event.TaskExecutionEvent` has occurred.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskExecution(self, request, context):
        """Fetches a :ref:`ref_flyteidl.admin.TaskExecution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTaskExecutions(self, request, context):
        """Fetches a list of :ref:`ref_flyteidl.admin.TaskExecution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskExecutionData(self, request, context):
        """Fetches input and output data for a :ref:`ref_flyteidl.admin.TaskExecution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProjectDomainAttributes(self, request, context):
        """Creates or updates custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project and domain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectDomainAttributes(self, request, context):
        """Fetches custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project and domain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProjectDomainAttributes(self, request, context):
        """Deletes custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project and domain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProjectAttributes(self, request, context):
        """Creates or updates custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` at the project level
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectAttributes(self, request, context):
        """Fetches custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project and domain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProjectAttributes(self, request, context):
        """Deletes custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project and domain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkflowAttributes(self, request, context):
        """Creates or updates custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project, domain and workflow.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkflowAttributes(self, request, context):
        """Fetches custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project, domain and workflow.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWorkflowAttributes(self, request, context):
        """Deletes custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a project, domain and workflow.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMatchableAttributes(self, request, context):
        """Lists custom :ref:`ref_flyteidl.admin.MatchableAttributesConfiguration` for a specific resource type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNamedEntities(self, request, context):
        """Returns a list of :ref:`ref_flyteidl.admin.NamedEntity` objects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNamedEntity(self, request, context):
        """Returns a :ref:`ref_flyteidl.admin.NamedEntity` object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNamedEntity(self, request, context):
        """Updates a :ref:`ref_flyteidl.admin.NamedEntity` object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDescriptionEntity(self, request, context):
        """Fetch a :ref:`ref_flyteidl.admin.DescriptionEntity` object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDescriptionEntities(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.DescriptionEntity` definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecutionMetrics(self, request, context):
        """Fetches runtime metrics for a :ref:`ref_flyteidl.admin.Execution`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTask': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTask,
                    request_deserializer=flyteidl_dot_admin_dot_task__pb2.TaskCreateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_task__pb2.TaskCreateResponse.SerializeToString,
            ),
            'GetTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTask,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_task__pb2.Task.SerializeToString,
            ),
            'ListTaskIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTaskIds,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.SerializeToString,
            ),
            'ListTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTasks,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_task__pb2.TaskList.SerializeToString,
            ),
            'CreateWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWorkflow,
                    request_deserializer=flyteidl_dot_admin_dot_workflow__pb2.WorkflowCreateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_workflow__pb2.WorkflowCreateResponse.SerializeToString,
            ),
            'GetWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkflow,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_workflow__pb2.Workflow.SerializeToString,
            ),
            'ListWorkflowIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkflowIds,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.SerializeToString,
            ),
            'ListWorkflows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkflows,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_workflow__pb2.WorkflowList.SerializeToString,
            ),
            'CreateLaunchPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLaunchPlan,
                    request_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanCreateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanCreateResponse.SerializeToString,
            ),
            'GetLaunchPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLaunchPlan,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlan.SerializeToString,
            ),
            'GetActiveLaunchPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveLaunchPlan,
                    request_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.ActiveLaunchPlanRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlan.SerializeToString,
            ),
            'ListActiveLaunchPlans': grpc.unary_unary_rpc_method_handler(
                    servicer.ListActiveLaunchPlans,
                    request_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.ActiveLaunchPlanListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanList.SerializeToString,
            ),
            'ListLaunchPlanIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLaunchPlanIds,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.SerializeToString,
            ),
            'ListLaunchPlans': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLaunchPlans,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanList.SerializeToString,
            ),
            'UpdateLaunchPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLaunchPlan,
                    request_deserializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanUpdateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanUpdateResponse.SerializeToString,
            ),
            'CreateExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateExecution,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.SerializeToString,
            ),
            'RelaunchExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.RelaunchExecution,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionRelaunchRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.SerializeToString,
            ),
            'RecoverExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.RecoverExecution,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionRecoverRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.SerializeToString,
            ),
            'GetExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecution,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.Execution.SerializeToString,
            ),
            'UpdateExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateExecution,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionUpdateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionUpdateResponse.SerializeToString,
            ),
            'GetExecutionData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecutionData,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetDataRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetDataResponse.SerializeToString,
            ),
            'ListExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExecutions,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionList.SerializeToString,
            ),
            'TerminateExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.TerminateExecution,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionTerminateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.ExecutionTerminateResponse.SerializeToString,
            ),
            'GetNodeExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodeExecution,
                    request_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecution.SerializeToString,
            ),
            'GetDynamicNodeWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDynamicNodeWorkflow,
                    request_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.GetDynamicNodeWorkflowRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_node__execution__pb2.DynamicNodeWorkflowResponse.SerializeToString,
            ),
            'ListNodeExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNodeExecutions,
                    request_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionList.SerializeToString,
            ),
            'ListNodeExecutionsForTask': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNodeExecutionsForTask,
                    request_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionForTaskListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionList.SerializeToString,
            ),
            'GetNodeExecutionData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodeExecutionData,
                    request_deserializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetDataRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetDataResponse.SerializeToString,
            ),
            'RegisterProject': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterProject,
                    request_deserializer=flyteidl_dot_admin_dot_project__pb2.ProjectRegisterRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__pb2.ProjectRegisterResponse.SerializeToString,
            ),
            'UpdateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProject,
                    request_deserializer=flyteidl_dot_admin_dot_project__pb2.Project.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__pb2.ProjectUpdateResponse.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=flyteidl_dot_admin_dot_project__pb2.ProjectGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__pb2.Project.SerializeToString,
            ),
            'ListProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjects,
                    request_deserializer=flyteidl_dot_admin_dot_project__pb2.ProjectListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__pb2.Projects.SerializeToString,
            ),
            'GetDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomains,
                    request_deserializer=flyteidl_dot_admin_dot_project__pb2.GetDomainRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__pb2.GetDomainsResponse.SerializeToString,
            ),
            'CreateWorkflowEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWorkflowEvent,
                    request_deserializer=flyteidl_dot_admin_dot_event__pb2.WorkflowExecutionEventRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_event__pb2.WorkflowExecutionEventResponse.SerializeToString,
            ),
            'CreateNodeEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNodeEvent,
                    request_deserializer=flyteidl_dot_admin_dot_event__pb2.NodeExecutionEventRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_event__pb2.NodeExecutionEventResponse.SerializeToString,
            ),
            'CreateTaskEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTaskEvent,
                    request_deserializer=flyteidl_dot_admin_dot_event__pb2.TaskExecutionEventRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_event__pb2.TaskExecutionEventResponse.SerializeToString,
            ),
            'GetTaskExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskExecution,
                    request_deserializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecution.SerializeToString,
            ),
            'ListTaskExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTaskExecutions,
                    request_deserializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionList.SerializeToString,
            ),
            'GetTaskExecutionData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskExecutionData,
                    request_deserializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetDataRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetDataResponse.SerializeToString,
            ),
            'UpdateProjectDomainAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProjectDomainAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesUpdateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesUpdateResponse.SerializeToString,
            ),
            'GetProjectDomainAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectDomainAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesGetResponse.SerializeToString,
            ),
            'DeleteProjectDomainAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProjectDomainAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesDeleteRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesDeleteResponse.SerializeToString,
            ),
            'UpdateProjectAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProjectAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesUpdateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesUpdateResponse.SerializeToString,
            ),
            'GetProjectAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesGetResponse.SerializeToString,
            ),
            'DeleteProjectAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProjectAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesDeleteRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesDeleteResponse.SerializeToString,
            ),
            'UpdateWorkflowAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkflowAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesUpdateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesUpdateResponse.SerializeToString,
            ),
            'GetWorkflowAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkflowAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesGetResponse.SerializeToString,
            ),
            'DeleteWorkflowAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWorkflowAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesDeleteRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesDeleteResponse.SerializeToString,
            ),
            'ListMatchableAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMatchableAttributes,
                    request_deserializer=flyteidl_dot_admin_dot_matchable__resource__pb2.ListMatchableAttributesRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_matchable__resource__pb2.ListMatchableAttributesResponse.SerializeToString,
            ),
            'ListNamedEntities': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamedEntities,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityList.SerializeToString,
            ),
            'GetNamedEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNamedEntity,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntity.SerializeToString,
            ),
            'UpdateNamedEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNamedEntity,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityUpdateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_common__pb2.NamedEntityUpdateResponse.SerializeToString,
            ),
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=flyteidl_dot_admin_dot_version__pb2.GetVersionRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_version__pb2.GetVersionResponse.SerializeToString,
            ),
            'GetDescriptionEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDescriptionEntity,
                    request_deserializer=flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntity.SerializeToString,
            ),
            'ListDescriptionEntities': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDescriptionEntities,
                    request_deserializer=flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntityListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntityList.SerializeToString,
            ),
            'GetExecutionMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecutionMetrics,
                    request_deserializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetMetricsRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetMetricsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'flyteidl.service.AdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AdminService(object):
    """The following defines an RPC service that is also served over HTTP via grpc-gateway.
    Standard response codes for both are defined here: https://github.com/grpc-ecosystem/grpc-gateway/blob/master/runtime/errors.go
    """

    @staticmethod
    def CreateTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/CreateTask',
            flyteidl_dot_admin_dot_task__pb2.TaskCreateRequest.SerializeToString,
            flyteidl_dot_admin_dot_task__pb2.TaskCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetTask',
            flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_task__pb2.Task.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTaskIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListTaskIds',
            flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.SerializeToString,
            flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListTasks',
            flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
            flyteidl_dot_admin_dot_task__pb2.TaskList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/CreateWorkflow',
            flyteidl_dot_admin_dot_workflow__pb2.WorkflowCreateRequest.SerializeToString,
            flyteidl_dot_admin_dot_workflow__pb2.WorkflowCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetWorkflow',
            flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_workflow__pb2.Workflow.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWorkflowIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListWorkflowIds',
            flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.SerializeToString,
            flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWorkflows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListWorkflows',
            flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
            flyteidl_dot_admin_dot_workflow__pb2.WorkflowList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLaunchPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/CreateLaunchPlan',
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanCreateRequest.SerializeToString,
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLaunchPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetLaunchPlan',
            flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlan.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveLaunchPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetActiveLaunchPlan',
            flyteidl_dot_admin_dot_launch__plan__pb2.ActiveLaunchPlanRequest.SerializeToString,
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlan.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListActiveLaunchPlans(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListActiveLaunchPlans',
            flyteidl_dot_admin_dot_launch__plan__pb2.ActiveLaunchPlanListRequest.SerializeToString,
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLaunchPlanIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListLaunchPlanIds',
            flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierListRequest.SerializeToString,
            flyteidl_dot_admin_dot_common__pb2.NamedEntityIdentifierList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLaunchPlans(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListLaunchPlans',
            flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLaunchPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/UpdateLaunchPlan',
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanUpdateRequest.SerializeToString,
            flyteidl_dot_admin_dot_launch__plan__pb2.LaunchPlanUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/CreateExecution',
            flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RelaunchExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/RelaunchExecution',
            flyteidl_dot_admin_dot_execution__pb2.ExecutionRelaunchRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecoverExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/RecoverExecution',
            flyteidl_dot_admin_dot_execution__pb2.ExecutionRecoverRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.ExecutionCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetExecution',
            flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.Execution.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/UpdateExecution',
            flyteidl_dot_admin_dot_execution__pb2.ExecutionUpdateRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.ExecutionUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExecutionData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetExecutionData',
            flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetDataRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListExecutions',
            flyteidl_dot_admin_dot_common__pb2.ResourceListRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.ExecutionList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TerminateExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/TerminateExecution',
            flyteidl_dot_admin_dot_execution__pb2.ExecutionTerminateRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.ExecutionTerminateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNodeExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetNodeExecution',
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecution.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDynamicNodeWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetDynamicNodeWorkflow',
            flyteidl_dot_admin_dot_node__execution__pb2.GetDynamicNodeWorkflowRequest.SerializeToString,
            flyteidl_dot_admin_dot_node__execution__pb2.DynamicNodeWorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNodeExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListNodeExecutions',
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionListRequest.SerializeToString,
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNodeExecutionsForTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListNodeExecutionsForTask',
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionForTaskListRequest.SerializeToString,
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNodeExecutionData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetNodeExecutionData',
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetDataRequest.SerializeToString,
            flyteidl_dot_admin_dot_node__execution__pb2.NodeExecutionGetDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/RegisterProject',
            flyteidl_dot_admin_dot_project__pb2.ProjectRegisterRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__pb2.ProjectRegisterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/UpdateProject',
            flyteidl_dot_admin_dot_project__pb2.Project.SerializeToString,
            flyteidl_dot_admin_dot_project__pb2.ProjectUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetProject',
            flyteidl_dot_admin_dot_project__pb2.ProjectGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListProjects',
            flyteidl_dot_admin_dot_project__pb2.ProjectListRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__pb2.Projects.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetDomains',
            flyteidl_dot_admin_dot_project__pb2.GetDomainRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__pb2.GetDomainsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWorkflowEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/CreateWorkflowEvent',
            flyteidl_dot_admin_dot_event__pb2.WorkflowExecutionEventRequest.SerializeToString,
            flyteidl_dot_admin_dot_event__pb2.WorkflowExecutionEventResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNodeEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/CreateNodeEvent',
            flyteidl_dot_admin_dot_event__pb2.NodeExecutionEventRequest.SerializeToString,
            flyteidl_dot_admin_dot_event__pb2.NodeExecutionEventResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTaskEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/CreateTaskEvent',
            flyteidl_dot_admin_dot_event__pb2.TaskExecutionEventRequest.SerializeToString,
            flyteidl_dot_admin_dot_event__pb2.TaskExecutionEventResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTaskExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetTaskExecution',
            flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_task__execution__pb2.TaskExecution.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTaskExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListTaskExecutions',
            flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionListRequest.SerializeToString,
            flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTaskExecutionData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetTaskExecutionData',
            flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetDataRequest.SerializeToString,
            flyteidl_dot_admin_dot_task__execution__pb2.TaskExecutionGetDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProjectDomainAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/UpdateProjectDomainAttributes',
            flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesUpdateRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectDomainAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetProjectDomainAttributes',
            flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProjectDomainAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/DeleteProjectDomainAttributes',
            flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesDeleteRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__domain__attributes__pb2.ProjectDomainAttributesDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProjectAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/UpdateProjectAttributes',
            flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesUpdateRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetProjectAttributes',
            flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProjectAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/DeleteProjectAttributes',
            flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesDeleteRequest.SerializeToString,
            flyteidl_dot_admin_dot_project__attributes__pb2.ProjectAttributesDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWorkflowAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/UpdateWorkflowAttributes',
            flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesUpdateRequest.SerializeToString,
            flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWorkflowAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetWorkflowAttributes',
            flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWorkflowAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/DeleteWorkflowAttributes',
            flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesDeleteRequest.SerializeToString,
            flyteidl_dot_admin_dot_workflow__attributes__pb2.WorkflowAttributesDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMatchableAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListMatchableAttributes',
            flyteidl_dot_admin_dot_matchable__resource__pb2.ListMatchableAttributesRequest.SerializeToString,
            flyteidl_dot_admin_dot_matchable__resource__pb2.ListMatchableAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNamedEntities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListNamedEntities',
            flyteidl_dot_admin_dot_common__pb2.NamedEntityListRequest.SerializeToString,
            flyteidl_dot_admin_dot_common__pb2.NamedEntityList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNamedEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetNamedEntity',
            flyteidl_dot_admin_dot_common__pb2.NamedEntityGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_common__pb2.NamedEntity.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNamedEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/UpdateNamedEntity',
            flyteidl_dot_admin_dot_common__pb2.NamedEntityUpdateRequest.SerializeToString,
            flyteidl_dot_admin_dot_common__pb2.NamedEntityUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetVersion',
            flyteidl_dot_admin_dot_version__pb2.GetVersionRequest.SerializeToString,
            flyteidl_dot_admin_dot_version__pb2.GetVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDescriptionEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetDescriptionEntity',
            flyteidl_dot_admin_dot_common__pb2.ObjectGetRequest.SerializeToString,
            flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntity.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDescriptionEntities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/ListDescriptionEntities',
            flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntityListRequest.SerializeToString,
            flyteidl_dot_admin_dot_description__entity__pb2.DescriptionEntityList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExecutionMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.AdminService/GetExecutionMetrics',
            flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetMetricsRequest.SerializeToString,
            flyteidl_dot_admin_dot_execution__pb2.WorkflowExecutionGetMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from flyteidl.admin import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDomainRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class Domain(_message.Message):
    __slots__ = ["id", "name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class GetDomainsResponse(_message.Message):
    __slots__ = ["domains"]
    DOMAINS_FIELD_NUMBER: _ClassVar[int]
    domains: _containers.RepeatedCompositeFieldContainer[Domain]
    def __init__(self, domains: _Optional[_Iterable[_Union[Domain, _Mapping]]] = ...) -> None: ...

class Project(_message.Message):
    __slots__ = ["id", "name", "domains", "description", "labels", "state", "org"]
    class ProjectState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        ACTIVE: _ClassVar[Project.ProjectState]
        ARCHIVED: _ClassVar[Project.ProjectState]
        SYSTEM_GENERATED: _ClassVar[Project.ProjectState]
        SYSTEM_ARCHIVED: _ClassVar[Project.ProjectState]
    ACTIVE: Project.ProjectState
    ARCHIVED: Project.ProjectState
    SYSTEM_GENERATED: Project.ProjectState
    SYSTEM_ARCHIVED: Project.ProjectState
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DOMAINS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    domains: _containers.RepeatedCompositeFieldContainer[Domain]
    description: str
    labels: _common_pb2.Labels
    state: Project.ProjectState
    org: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., domains: _Optional[_Iterable[_Union[Domain, _Mapping]]] = ..., description: _Optional[str] = ..., labels: _Optional[_Union[_common_pb2.Labels, _Mapping]] = ..., state: _Optional[_Union[Project.ProjectState, str]] = ..., org: _Optional[str] = ...) -> None: ...

class Projects(_message.Message):
    __slots__ = ["projects", "token"]
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedCompositeFieldContainer[Project]
    token: str
    def __init__(self, projects: _Optional[_Iterable[_Union[Project, _Mapping]]] = ..., token: _Optional[str] = ...) -> None: ...

class ProjectListRequest(_message.Message):
    __slots__ = ["limit", "token", "filters", "sort_by", "org"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    limit: int
    token: str
    filters: str
    sort_by: _common_pb2.Sort
    org: str
    def __init__(self, limit: _Optional[int] = ..., token: _Optional[str] = ..., filters: _Optional[str] = ..., sort_by: _Optional[_Union[_common_pb2.Sort, _Mapping]] = ..., org: _Optional[str] = ...) -> None: ...

class ProjectRegisterRequest(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: Project
    def __init__(self, project: _Optional[_Union[Project, _Mapping]] = ...) -> None: ...

class ProjectRegisterResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ProjectUpdateResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ProjectGetRequest(_message.Message):
    __slots__ = ["id", "org"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    id: str
    org: str
    def __init__(self, id: _Optional[str] = ..., org: _Optional[str] = ...) -> None: ...

class InactiveProject(_message.Message):
    __slots__ = ["id", "org"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    id: str
    org: str
    def __init__(self, id: _Optional[str] = ..., org: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/event/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import compiler_pb2 as flyteidl_dot_core_dot_compiler__pb2
from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import catalog_pb2 as flyteidl_dot_core_dot_catalog__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x66lyteidl/event/event.proto\x12\x0e\x66lyteidl.event\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1c\x66lyteidl/core/compiler.proto\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1b\x66lyteidl/core/catalog.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xaa\x03\n\x16WorkflowExecutionEvent\x12M\n\x0c\x65xecution_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifierR\x0b\x65xecutionId\x12\x1f\n\x0bproducer_id\x18\x02 \x01(\tR\nproducerId\x12<\n\x05phase\x18\x03 \x01(\x0e\x32&.flyteidl.core.WorkflowExecution.PhaseR\x05phase\x12;\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x1f\n\noutput_uri\x18\x05 \x01(\tH\x00R\toutputUri\x12\x35\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00R\x05\x65rror\x12<\n\x0boutput_data\x18\x07 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00R\noutputDataB\x0f\n\routput_result\"\xb4\n\n\x12NodeExecutionEvent\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifierR\x02id\x12\x1f\n\x0bproducer_id\x18\x02 \x01(\tR\nproducerId\x12\x38\n\x05phase\x18\x03 \x01(\x0e\x32\".flyteidl.core.NodeExecution.PhaseR\x05phase\x12;\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x1d\n\tinput_uri\x18\x05 \x01(\tH\x00R\x08inputUri\x12:\n\ninput_data\x18\x14 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00R\tinputData\x12\x1f\n\noutput_uri\x18\x06 \x01(\tH\x01R\toutputUri\x12\x35\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x01R\x05\x65rror\x12<\n\x0boutput_data\x18\x0f \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x01R\noutputData\x12\\\n\x16workflow_node_metadata\x18\x08 \x01(\x0b\x32$.flyteidl.event.WorkflowNodeMetadataH\x02R\x14workflowNodeMetadata\x12P\n\x12task_node_metadata\x18\x0e \x01(\x0b\x32 .flyteidl.event.TaskNodeMetadataH\x02R\x10taskNodeMetadata\x12]\n\x14parent_task_metadata\x18\t \x01(\x0b\x32+.flyteidl.event.ParentTaskExecutionMetadataR\x12parentTaskMetadata\x12]\n\x14parent_node_metadata\x18\n \x01(\x0b\x32+.flyteidl.event.ParentNodeExecutionMetadataR\x12parentNodeMetadata\x12\x1f\n\x0bretry_group\x18\x0b \x01(\tR\nretryGroup\x12 \n\x0cspec_node_id\x18\x0c \x01(\tR\nspecNodeId\x12\x1b\n\tnode_name\x18\r \x01(\tR\x08nodeName\x12#\n\revent_version\x18\x10 \x01(\x05R\x0c\x65ventVersion\x12\x1b\n\tis_parent\x18\x11 \x01(\x08R\x08isParent\x12\x1d\n\nis_dynamic\x18\x12 \x01(\x08R\tisDynamic\x12\x19\n\x08\x64\x65\x63k_uri\x18\x13 \x01(\tR\x07\x64\x65\x63kUri\x12;\n\x0breported_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nreportedAt\x12\x19\n\x08is_array\x18\x16 \x01(\x08R\x07isArray\x12>\n\rtarget_entity\x18\x17 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x0ctargetEntity\x12-\n\x13is_in_dynamic_chain\x18\x18 \x01(\x08R\x10isInDynamicChain\x12\x19\n\x08is_eager\x18\x19 \x01(\x08R\x07isEagerB\r\n\x0binput_valueB\x0f\n\routput_resultB\x11\n\x0ftarget_metadata\"e\n\x14WorkflowNodeMetadata\x12M\n\x0c\x65xecution_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifierR\x0b\x65xecutionId\"\xf1\x02\n\x10TaskNodeMetadata\x12\x44\n\x0c\x63\x61\x63he_status\x18\x01 \x01(\x0e\x32!.flyteidl.core.CatalogCacheStatusR\x0b\x63\x61\x63heStatus\x12?\n\x0b\x63\x61talog_key\x18\x02 \x01(\x0b\x32\x1e.flyteidl.core.CatalogMetadataR\ncatalogKey\x12W\n\x12reservation_status\x18\x03 \x01(\x0e\x32(.flyteidl.core.CatalogReservation.StatusR\x11reservationStatus\x12%\n\x0e\x63heckpoint_uri\x18\x04 \x01(\tR\rcheckpointUri\x12V\n\x10\x64ynamic_workflow\x18\x10 \x01(\x0b\x32+.flyteidl.event.DynamicWorkflowNodeMetadataR\x0f\x64ynamicWorkflow\"\xce\x01\n\x1b\x44ynamicWorkflowNodeMetadata\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\x12S\n\x11\x63ompiled_workflow\x18\x02 \x01(\x0b\x32&.flyteidl.core.CompiledWorkflowClosureR\x10\x63ompiledWorkflow\x12/\n\x14\x64ynamic_job_spec_uri\x18\x03 \x01(\tR\x11\x64ynamicJobSpecUri\"U\n\x1bParentTaskExecutionMetadata\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32&.flyteidl.core.TaskExecutionIdentifierR\x02id\"6\n\x1bParentNodeExecutionMetadata\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\"b\n\x0b\x45ventReason\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x12;\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\"\x97\x08\n\x12TaskExecutionEvent\x12\x32\n\x07task_id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x06taskId\x12_\n\x18parent_node_execution_id\x18\x02 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifierR\x15parentNodeExecutionId\x12#\n\rretry_attempt\x18\x03 \x01(\rR\x0cretryAttempt\x12\x38\n\x05phase\x18\x04 \x01(\x0e\x32\".flyteidl.core.TaskExecution.PhaseR\x05phase\x12\x1f\n\x0bproducer_id\x18\x05 \x01(\tR\nproducerId\x12*\n\x04logs\x18\x06 \x03(\x0b\x32\x16.flyteidl.core.TaskLogR\x04logs\x12;\n\x0boccurred_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x1d\n\tinput_uri\x18\x08 \x01(\tH\x00R\x08inputUri\x12:\n\ninput_data\x18\x13 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00R\tinputData\x12\x1f\n\noutput_uri\x18\t \x01(\tH\x01R\toutputUri\x12\x35\n\x05\x65rror\x18\n \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x01R\x05\x65rror\x12<\n\x0boutput_data\x18\x11 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x01R\noutputData\x12\x38\n\x0b\x63ustom_info\x18\x0b \x01(\x0b\x32\x17.google.protobuf.StructR\ncustomInfo\x12#\n\rphase_version\x18\x0c \x01(\rR\x0cphaseVersion\x12\x1a\n\x06reason\x18\r \x01(\tB\x02\x18\x01R\x06reason\x12\x35\n\x07reasons\x18\x15 \x03(\x0b\x32\x1b.flyteidl.event.EventReasonR\x07reasons\x12\x1b\n\ttask_type\x18\x0e \x01(\tR\x08taskType\x12\x41\n\x08metadata\x18\x10 \x01(\x0b\x32%.flyteidl.event.TaskExecutionMetadataR\x08metadata\x12#\n\revent_version\x18\x12 \x01(\x05R\x0c\x65ventVersion\x12;\n\x0breported_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nreportedAtB\r\n\x0binput_valueB\x0f\n\routput_result\"\xc9\x03\n\x14\x45xternalResourceInfo\x12\x1f\n\x0b\x65xternal_id\x18\x01 \x01(\tR\nexternalId\x12\x14\n\x05index\x18\x02 \x01(\rR\x05index\x12#\n\rretry_attempt\x18\x03 \x01(\rR\x0cretryAttempt\x12\x38\n\x05phase\x18\x04 \x01(\x0e\x32\".flyteidl.core.TaskExecution.PhaseR\x05phase\x12\x44\n\x0c\x63\x61\x63he_status\x18\x05 \x01(\x0e\x32!.flyteidl.core.CatalogCacheStatusR\x0b\x63\x61\x63heStatus\x12*\n\x04logs\x18\x06 \x03(\x0b\x32\x16.flyteidl.core.TaskLogR\x04logs\x12\\\n\x16workflow_node_metadata\x18\x07 \x01(\x0b\x32$.flyteidl.event.WorkflowNodeMetadataH\x00R\x14workflowNodeMetadata\x12\x38\n\x0b\x63ustom_info\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructR\ncustomInfoB\x11\n\x0ftarget_metadata\"[\n\x10ResourcePoolInfo\x12)\n\x10\x61llocation_token\x18\x01 \x01(\tR\x0f\x61llocationToken\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\"\x9d\x03\n\x15TaskExecutionMetadata\x12%\n\x0egenerated_name\x18\x01 \x01(\tR\rgeneratedName\x12S\n\x12\x65xternal_resources\x18\x02 \x03(\x0b\x32$.flyteidl.event.ExternalResourceInfoR\x11\x65xternalResources\x12N\n\x12resource_pool_info\x18\x03 \x03(\x0b\x32 .flyteidl.event.ResourcePoolInfoR\x10resourcePoolInfo\x12+\n\x11plugin_identifier\x18\x04 \x01(\tR\x10pluginIdentifier\x12Z\n\x0einstance_class\x18\x10 \x01(\x0e\x32\x33.flyteidl.event.TaskExecutionMetadata.InstanceClassR\rinstanceClass\"/\n\rInstanceClass\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x11\n\rINTERRUPTIBLE\x10\x01\x42\xb6\x01\n\x12\x63om.flyteidl.eventB\nEventProtoP\x01Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/event\xa2\x02\x03\x46\x45X\xaa\x02\x0e\x46lyteidl.Event\xca\x02\x0e\x46lyteidl\\Event\xe2\x02\x1a\x46lyteidl\\Event\\GPBMetadata\xea\x02\x0f\x46lyteidl::Eventb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.event.event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.eventB\nEventProtoP\001Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/event\242\002\003FEX\252\002\016Flyteidl.Event\312\002\016Flyteidl\\Event\342\002\032Flyteidl\\Event\\GPBMetadata\352\002\017Flyteidl::Event'
  _TASKEXECUTIONEVENT.fields_by_name['reason']._options = None
  _TASKEXECUTIONEVENT.fields_by_name['reason']._serialized_options = b'\030\001'
  _globals['_WORKFLOWEXECUTIONEVENT']._serialized_start=262
  _globals['_WORKFLOWEXECUTIONEVENT']._serialized_end=688
  _globals['_NODEEXECUTIONEVENT']._serialized_start=691
  _globals['_NODEEXECUTIONEVENT']._serialized_end=2023
  _globals['_WORKFLOWNODEMETADATA']._serialized_start=2025
  _globals['_WORKFLOWNODEMETADATA']._serialized_end=2126
  _globals['_TASKNODEMETADATA']._serialized_start=2129
  _globals['_TASKNODEMETADATA']._serialized_end=2498
  _globals['_DYNAMICWORKFLOWNODEMETADATA']._serialized_start=2501
  _globals['_DYNAMICWORKFLOWNODEMETADATA']._serialized_end=2707
  _globals['_PARENTTASKEXECUTIONMETADATA']._serialized_start=2709
  _globals['_PARENTTASKEXECUTIONMETADATA']._serialized_end=2794
  _globals['_PARENTNODEEXECUTIONMETADATA']._serialized_start=2796
  _globals['_PARENTNODEEXECUTIONMETADATA']._serialized_end=2850
  _globals['_EVENTREASON']._serialized_start=2852
  _globals['_EVENTREASON']._serialized_end=2950
  _globals['_TASKEXECUTIONEVENT']._serialized_start=2953
  _globals['_TASKEXECUTIONEVENT']._serialized_end=4000
  _globals['_EXTERNALRESOURCEINFO']._serialized_start=4003
  _globals['_EXTERNALRESOURCEINFO']._serialized_end=4460
  _globals['_RESOURCEPOOLINFO']._serialized_start=4462
  _globals['_RESOURCEPOOLINFO']._serialized_end=4553
  _globals['_TASKEXECUTIONMETADATA']._serialized_start=4556
  _globals['_TASKEXECUTIONMETADATA']._serialized_end=4969
  _globals['_TASKEXECUTIONMETADATA_INSTANCECLASS']._serialized_start=4922
  _globals['_TASKEXECUTIONMETADATA_INSTANCECLASS']._serialized_end=4969
# @@protoc_insertion_point(module_scope)



from google.api import annotations_pb2 as _annotations_pb2
from flyteidl.admin import signal_pb2 as _signal_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/launch_plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import execution_envs_pb2 as flyteidl_dot_core_dot_execution__envs__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import interface_pb2 as flyteidl_dot_core_dot_interface__pb2
from flyteidl.core import security_pb2 as flyteidl_dot_core_dot_security__pb2
from flyteidl.admin import schedule_pb2 as flyteidl_dot_admin_dot_schedule__pb2
from flyteidl.admin import cluster_assignment_pb2 as flyteidl_dot_admin_dot_cluster__assignment__pb2
from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n flyteidl/admin/launch_plan.proto\x12\x0e\x66lyteidl.admin\x1a\x1d\x66lyteidl/core/execution.proto\x1a\"flyteidl/core/execution_envs.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1d\x66lyteidl/core/interface.proto\x1a\x1c\x66lyteidl/core/security.proto\x1a\x1d\x66lyteidl/admin/schedule.proto\x1a\'flyteidl/admin/cluster_assignment.proto\x1a\x1b\x66lyteidl/admin/common.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"x\n\x17LaunchPlanCreateRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.flyteidl.admin.LaunchPlanSpecR\x04spec\"\x1a\n\x18LaunchPlanCreateResponse\"\xa8\x01\n\nLaunchPlan\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.flyteidl.admin.LaunchPlanSpecR\x04spec\x12;\n\x07\x63losure\x18\x03 \x01(\x0b\x32!.flyteidl.admin.LaunchPlanClosureR\x07\x63losure\"e\n\x0eLaunchPlanList\x12=\n\x0claunch_plans\x18\x01 \x03(\x0b\x32\x1a.flyteidl.admin.LaunchPlanR\x0blaunchPlans\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\"v\n\x04\x41uth\x12,\n\x12\x61ssumable_iam_role\x18\x01 \x01(\tR\x10\x61ssumableIamRole\x12<\n\x1akubernetes_service_account\x18\x02 \x01(\tR\x18kubernetesServiceAccount:\x02\x18\x01\"\xf2\x08\n\x0eLaunchPlanSpec\x12:\n\x0bworkflow_id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\nworkflowId\x12K\n\x0f\x65ntity_metadata\x18\x02 \x01(\x0b\x32\".flyteidl.admin.LaunchPlanMetadataR\x0e\x65ntityMetadata\x12\x42\n\x0e\x64\x65\x66\x61ult_inputs\x18\x03 \x01(\x0b\x32\x1b.flyteidl.core.ParameterMapR\rdefaultInputs\x12<\n\x0c\x66ixed_inputs\x18\x04 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapR\x0b\x66ixedInputs\x12\x16\n\x04role\x18\x05 \x01(\tB\x02\x18\x01R\x04role\x12.\n\x06labels\x18\x06 \x01(\x0b\x32\x16.flyteidl.admin.LabelsR\x06labels\x12=\n\x0b\x61nnotations\x18\x07 \x01(\x0b\x32\x1b.flyteidl.admin.AnnotationsR\x0b\x61nnotations\x12,\n\x04\x61uth\x18\x08 \x01(\x0b\x32\x14.flyteidl.admin.AuthB\x02\x18\x01R\x04\x61uth\x12\x39\n\tauth_role\x18\t \x01(\x0b\x32\x18.flyteidl.admin.AuthRoleB\x02\x18\x01R\x08\x61uthRole\x12I\n\x10security_context\x18\n \x01(\x0b\x32\x1e.flyteidl.core.SecurityContextR\x0fsecurityContext\x12M\n\x12quality_of_service\x18\x10 \x01(\x0b\x32\x1f.flyteidl.core.QualityOfServiceR\x10qualityOfService\x12X\n\x16raw_output_data_config\x18\x11 \x01(\x0b\x32#.flyteidl.admin.RawOutputDataConfigR\x13rawOutputDataConfig\x12\'\n\x0fmax_parallelism\x18\x12 \x01(\x05R\x0emaxParallelism\x12@\n\rinterruptible\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\rinterruptible\x12\'\n\x0foverwrite_cache\x18\x14 \x01(\x08R\x0eoverwriteCache\x12(\n\x04\x65nvs\x18\x15 \x01(\x0b\x32\x14.flyteidl.admin.EnvsR\x04\x65nvs\x12\x61\n\x19\x65xecution_env_assignments\x18\x16 \x03(\x0b\x32%.flyteidl.core.ExecutionEnvAssignmentR\x17\x65xecutionEnvAssignments\x12P\n\x12\x63luster_assignment\x18\x17 \x01(\x0b\x32!.flyteidl.admin.ClusterAssignmentR\x11\x63lusterAssignment\"\xcd\x02\n\x11LaunchPlanClosure\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x1f.flyteidl.admin.LaunchPlanStateR\x05state\x12\x44\n\x0f\x65xpected_inputs\x18\x02 \x01(\x0b\x32\x1b.flyteidl.core.ParameterMapR\x0e\x65xpectedInputs\x12\x45\n\x10\x65xpected_outputs\x18\x03 \x01(\x0b\x32\x1a.flyteidl.core.VariableMapR\x0f\x65xpectedOutputs\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\xd1\x01\n\x12LaunchPlanMetadata\x12\x34\n\x08schedule\x18\x01 \x01(\x0b\x32\x18.flyteidl.admin.ScheduleR\x08schedule\x12\x42\n\rnotifications\x18\x02 \x03(\x0b\x32\x1c.flyteidl.admin.NotificationR\rnotifications\x12\x41\n\x11launch_conditions\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyR\x10launchConditions\"{\n\x17LaunchPlanUpdateRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\x12\x35\n\x05state\x18\x02 \x01(\x0e\x32\x1f.flyteidl.admin.LaunchPlanStateR\x05state\"\x1a\n\x18LaunchPlanUpdateResponse\"P\n\x17\x41\x63tiveLaunchPlanRequest\x12\x35\n\x02id\x18\x01 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifierR\x02id\"\xbc\x01\n\x1b\x41\x63tiveLaunchPlanListRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12\x14\n\x05limit\x18\x03 \x01(\rR\x05limit\x12\x14\n\x05token\x18\x04 \x01(\tR\x05token\x12-\n\x07sort_by\x18\x05 \x01(\x0b\x32\x14.flyteidl.admin.SortR\x06sortBy\x12\x10\n\x03org\x18\x06 \x01(\tR\x03org*+\n\x0fLaunchPlanState\x12\x0c\n\x08INACTIVE\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x42\xbb\x01\n\x12\x63om.flyteidl.adminB\x0fLaunchPlanProtoP\x01Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\xa2\x02\x03\x46\x41X\xaa\x02\x0e\x46lyteidl.Admin\xca\x02\x0e\x46lyteidl\\Admin\xe2\x02\x1a\x46lyteidl\\Admin\\GPBMetadata\xea\x02\x0f\x46lyteidl::Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.admin.launch_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.adminB\017LaunchPlanProtoP\001Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\242\002\003FAX\252\002\016Flyteidl.Admin\312\002\016Flyteidl\\Admin\342\002\032Flyteidl\\Admin\\GPBMetadata\352\002\017Flyteidl::Admin'
  _AUTH._options = None
  _AUTH._serialized_options = b'\030\001'
  _LAUNCHPLANSPEC.fields_by_name['role']._options = None
  _LAUNCHPLANSPEC.fields_by_name['role']._serialized_options = b'\030\001'
  _LAUNCHPLANSPEC.fields_by_name['auth']._options = None
  _LAUNCHPLANSPEC.fields_by_name['auth']._serialized_options = b'\030\001'
  _LAUNCHPLANSPEC.fields_by_name['auth_role']._options = None
  _LAUNCHPLANSPEC.fields_by_name['auth_role']._serialized_options = b'\030\001'
  _globals['_LAUNCHPLANSTATE']._serialized_start=3094
  _globals['_LAUNCHPLANSTATE']._serialized_end=3137
  _globals['_LAUNCHPLANCREATEREQUEST']._serialized_start=435
  _globals['_LAUNCHPLANCREATEREQUEST']._serialized_end=555
  _globals['_LAUNCHPLANCREATERESPONSE']._serialized_start=557
  _globals['_LAUNCHPLANCREATERESPONSE']._serialized_end=583
  _globals['_LAUNCHPLAN']._serialized_start=586
  _globals['_LAUNCHPLAN']._serialized_end=754
  _globals['_LAUNCHPLANLIST']._serialized_start=756
  _globals['_LAUNCHPLANLIST']._serialized_end=857
  _globals['_AUTH']._serialized_start=859
  _globals['_AUTH']._serialized_end=977
  _globals['_LAUNCHPLANSPEC']._serialized_start=980
  _globals['_LAUNCHPLANSPEC']._serialized_end=2118
  _globals['_LAUNCHPLANCLOSURE']._serialized_start=2121
  _globals['_LAUNCHPLANCLOSURE']._serialized_end=2454
  _globals['_LAUNCHPLANMETADATA']._serialized_start=2457
  _globals['_LAUNCHPLANMETADATA']._serialized_end=2666
  _globals['_LAUNCHPLANUPDATEREQUEST']._serialized_start=2668
  _globals['_LAUNCHPLANUPDATEREQUEST']._serialized_end=2791
  _globals['_LAUNCHPLANUPDATERESPONSE']._serialized_start=2793
  _globals['_LAUNCHPLANUPDATERESPONSE']._serialized_end=2819
  _globals['_ACTIVELAUNCHPLANREQUEST']._serialized_start=2821
  _globals['_ACTIVELAUNCHPLANREQUEST']._serialized_end=2901
  _globals['_ACTIVELAUNCHPLANLISTREQUEST']._serialized_start=2904
  _globals['_ACTIVELAUNCHPLANLISTREQUEST']._serialized_end=3092
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.event import event_pb2 as flyteidl_dot_event_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x66lyteidl/admin/event.proto\x12\x0e\x66lyteidl.admin\x1a\x1a\x66lyteidl/event/event.proto\"G\n EventErrorAlreadyInTerminalState\x12#\n\rcurrent_phase\x18\x01 \x01(\tR\x0c\x63urrentPhase\"9\n\x1d\x45ventErrorIncompatibleCluster\x12\x18\n\x07\x63luster\x18\x01 \x01(\tR\x07\x63luster\"\xf1\x01\n\x12\x45ventFailureReason\x12m\n\x19\x61lready_in_terminal_state\x18\x01 \x01(\x0b\x32\x30.flyteidl.admin.EventErrorAlreadyInTerminalStateH\x00R\x16\x61lreadyInTerminalState\x12\x62\n\x14incompatible_cluster\x18\x02 \x01(\x0b\x32-.flyteidl.admin.EventErrorIncompatibleClusterH\x00R\x13incompatibleClusterB\x08\n\x06reason\"|\n\x1dWorkflowExecutionEventRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12<\n\x05\x65vent\x18\x02 \x01(\x0b\x32&.flyteidl.event.WorkflowExecutionEventR\x05\x65vent\" \n\x1eWorkflowExecutionEventResponse\"t\n\x19NodeExecutionEventRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x38\n\x05\x65vent\x18\x02 \x01(\x0b\x32\".flyteidl.event.NodeExecutionEventR\x05\x65vent\"\x1c\n\x1aNodeExecutionEventResponse\"t\n\x19TaskExecutionEventRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x38\n\x05\x65vent\x18\x02 \x01(\x0b\x32\".flyteidl.event.TaskExecutionEventR\x05\x65vent\"\x1c\n\x1aTaskExecutionEventResponseB\xb6\x01\n\x12\x63om.flyteidl.adminB\nEventProtoP\x01Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\xa2\x02\x03\x46\x41X\xaa\x02\x0e\x46lyteidl.Admin\xca\x02\x0e\x46lyteidl\\Admin\xe2\x02\x1a\x46lyteidl\\Admin\\GPBMetadata\xea\x02\x0f\x46lyteidl::Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.admin.event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.adminB\nEventProtoP\001Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\242\002\003FAX\252\002\016Flyteidl.Admin\312\002\016Flyteidl\\Admin\342\002\032Flyteidl\\Admin\\GPBMetadata\352\002\017Flyteidl::Admin'
  _globals['_EVENTERRORALREADYINTERMINALSTATE']._serialized_start=74
  _globals['_EVENTERRORALREADYINTERMINALSTATE']._serialized_end=145
  _globals['_EVENTERRORINCOMPATIBLECLUSTER']._serialized_start=147
  _globals['_EVENTERRORINCOMPATIBLECLUSTER']._serialized_end=204
  _globals['_EVENTFAILUREREASON']._serialized_start=207
  _globals['_EVENTFAILUREREASON']._serialized_end=448
  _globals['_WORKFLOWEXECUTIONEVENTREQUEST']._serialized_start=450
  _globals['_WORKFLOWEXECUTIONEVENTREQUEST']._serialized_end=574
  _globals['_WORKFLOWEXECUTIONEVENTRESPONSE']._serialized_start=576
  _globals['_WORKFLOWEXECUTIONEVENTRESPONSE']._serialized_end=608
  _globals['_NODEEXECUTIONEVENTREQUEST']._serialized_start=610
  _globals['_NODEEXECUTIONEVENTREQUEST']._serialized_end=726
  _globals['_NODEEXECUTIONEVENTRESPONSE']._serialized_start=728
  _globals['_NODEEXECUTIONEVENTRESPONSE']._serialized_end=756
  _globals['_TASKEXECUTIONEVENTREQUEST']._serialized_start=758
  _globals['_TASKEXECUTIONEVENTREQUEST']._serialized_end=874
  _globals['_TASKEXECUTIONEVENTRESPONSE']._serialized_start=876
  _globals['_TASKEXECUTIONEVENTRESPONSE']._serialized_end=904
# @@protoc_insertion_point(module_scope)
